<?php

/**
 * Déclaration de la classe CommandLine\Argument\AbstractArgument.
 */
namespace jrosset\CommandLine\Argument;

/**
 * Classe abstraite pour n'importe quel type de paramètre
 *
 * @package CommandLine\Argument
 */
abstract class ArgumentAbstract implements IArgument {
    /**
     * @var string Le nom de la variable de retour de l'argument.
     */
    protected string $varName;
    /**
     * @var string Le nom de l'argument.
     */
    protected string $name;
    /**
     * @var string|null La description de l'argument.
     */
    protected ?string $description;

    /**
     * @var mixed|null La valeur par défaut. Null si aucune.
     */
    protected $_default = null;

    /**
     * Crée un nouvel argument.
     *
     * @param string      $name        Le nom de l'argument
     * @param string|null $description La description de l'argument
     */
    protected function __construct (string $name, ?string $description) {
        $this->setName($name);
        $this->setDescription($description);
    }

    /**
     * @inheritDoc
     */
    public function getVarName (): string {
        return $this->varName;
    }
    /**
     * Définit le nom de la variable de retour de l'argument.
     *
     * @param string $varName Le nom
     *
     * @return $this
     *
     * @see $name
     */
    public function setVarName (string $varName): self {
        $this->varName = $varName;
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function getName (): string {
        return $this->name;
    }
    /**
     * Définit le nom de l'argument.
     *
     * @param string  $name           Le nom
     * @param boolean $replaceVarName Remplacer également le nom de la variable de retour ?
     *
     * @return $this
     *
     * @see $name
     */
    public function setName (string $name, bool $replaceVarName = true): self {
        $this->name = $name;
        if ($replaceVarName) {
            $this->setVarName($name);
        }
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function getDescription (): ?string {
        return $this->description;
    }
    /**
     * Définit la description de l'argument.
     *
     * @param string|null $description La description
     *
     * @return $this
     *
     * @see $description
     */
    public function setDescription (?string $description): self {
        $this->description = $description;
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function getDefault () {
        return $this->_default;
    }
    /**
     * Définit le valeur par défaut
     *
     * @param mixed|null $default La valeur par défaut.
     *
     * @return $this
     *
     * @see $_default
     */
    public function setDefault ($default = null): self {
        $this->_default = $default;
        return $this;
    }
}