<?php
/**
 * Déclare la classe CommandLine\Argument\Option\Flag.
 */

namespace jrosset\CommandLine\Argument\Option;

use InvalidArgumentException;
use jrosset\CommandLine\Argument\ParseResult;

/**
 * Option de type "flag" contenant True ou False
 *
 * Si fourni, retournera la valeur inverse de {@see getDefault() getDefault}
 *
 * @package CommandLine\Argument\Option
 * @see     FlagReverse
 *
 */
class Flag extends OptionAbstract {
    /**
     * Crée un nouvel argument de type option
     *
     * @param string      $name        Le nom
     * @param bool        $default     La valeur par défaut
     * @param string|null $description La description
     * @param string|null $tagLong     Le tag long
     * @param string|null $tagShort    Le tag court
     */
    public function __construct (string $name, bool $default, ?string $description, ?string $tagLong = null, ?string $tagShort = null) {
        parent::__construct($name, $description, $tagLong, $tagShort);
        $this->setDefault($default);
    }

    /**
     * @inheritDoc
     */
    public function parse (array $args): ?ParseResult {
        if ($this->_parseTag($args[0])) {
            return new ParseResult(true, 1);
        }

        return null;
    }

    /**
     * Définit la valeur par défaut
     *
     * @param boolean $default La valeur par défaut.
     *
     * @return $this
     */
    public function setDefault ($default = null): self {
        if (!is_bool($default)) {
            throw new InvalidArgumentException('La valeur par défaut DOIT être un booléen');
        }

        parent::setDefault($default);
        return $this;
    }
}