<?php
/**
 * Déclaration de CommandLine\Argument\Value\FixedValue
 */
namespace jrosset\CommandLine\Argument\Value;

use jrosset\CommandLine\Argument\IArgumentValueDescription;
use jrosset\CommandLine\Argument\ParseResult;

/**
 * Argument devant correspondre une valeur fixe
 *
 * @package      CommandLine\Argument
 *
 * @noinspection PhpUnused
 */
class FixedValue extends ValueAbstract implements IArgumentValueDescription {
    /**
     * @var string La valeur que doit avoir l'argument
     */
    protected string $value;

    /**
     * Crée un nouvel argument de type valeur
     *
     * @param string      $varName     Le nom de la variable
     * @param string      $value       La valeur
     * @param string|null $description La description
     * @param boolean     $optional    Valeur optionnelle ?
     */
    public function __construct (string $varName, string $value, ?string $description, bool $optional) {
        parent::__construct($value, $description, $optional);
        $this->setVarName($varName);
        $this->setValue($value);
    }

    /**
     * @inheritDoc
     */
    public function parse (array $args): ?ParseResult {
        if ($args[0] == $this->getValue()) {
            return new ParseResult($this->getValue(), 1);
        }

        return null;
    }

    /**
     * @inheritDoc
     */
    public function getValueDescription (): string {
        return '"' . $this->getValue() . '"';
    }

    /**
     * La valeur.
     *
     * @return string La valeur.
     *
     * @see $value
     */
    public function getValue (): string {
        return $this->value;
    }
    /**
     * Définit la valeur
     *
     * @param string $value La valeur
     *
     * @return $this
     * @see $value
     */
    public function setValue (string $value): self {
        $this->value = $value;
        return $this;
    }
}